@@ -1,11 +1,7 @@
-{-# LANGUAGE CPP, NoImplicitPrelude #-}
+{-# LANGUAGE NoImplicitPrelude #-}
 module Foreign.ForeignPtr.Unsafe.Compat (
   -- ** Unsafe low-level operations
   unsafeForeignPtrToPtr
 ) where
 
-#if MIN_VERSION_base(4,6,0)
 import Foreign.ForeignPtr.Unsafe (unsafeForeignPtrToPtr)
-#else
-import Foreign.ForeignPtr (unsafeForeignPtrToPtr)
-#endif
